@@ -4,18 +4,15 @@
  * over udp to one or multiple endpoints
  * \author Álvaro Cebrián Juan, 2019. acebrianjuan(at)gmail.com
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #ifndef GNSS_SDR_MONITOR_PVT_UDP_SINK_H
@@ -28,7 +25,13 @@
 #include <string>
 #include <vector>
 
-#if BOOST_GREATER_1_65
+/** \addtogroup PVT
+ * \{ */
+/** \addtogroup PVT_libs
+ * \{ */
+
+
+#if USE_BOOST_ASIO_IO_CONTEXT
 using b_io_context = boost::asio::io_context;
 #else
 using b_io_context = boost::asio::io_service;
@@ -38,16 +41,18 @@ class Monitor_Pvt_Udp_Sink
 {
 public:
     Monitor_Pvt_Udp_Sink(const std::vector<std::string>& addresses, const uint16_t& port, bool protobuf_enabled);
-    bool write_monitor_pvt(const std::shared_ptr<Monitor_Pvt>& monitor_pvt);
+    bool write_monitor_pvt(const Monitor_Pvt* const monitor_pvt);
 
 private:
+    Serdes_Monitor_Pvt serdes;
     b_io_context io_context;
     boost::asio::ip::udp::socket socket;
-    boost::system::error_code error;
     std::vector<boost::asio::ip::udp::endpoint> endpoints;
-    Serdes_Monitor_Pvt serdes;
+    boost::system::error_code error;
     bool use_protobuf;
 };
 
 
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_MONITOR_PVT_UDP_SINK_H
