@@ -10,7 +10,7 @@
  * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2022  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -22,7 +22,6 @@
 #include "galileo_e5_signal_replica.h"
 #include "gnss_sdr_fft.h"
 #include "gnss_sdr_flags.h"
-#include "uio_fpga.h"
 #include <glog/logging.h>
 #include <gnuradio/gr_complex.h>  // for gr_complex
 #include <volk/volk.h>            // for volk_32fc_conjugate_32fc
@@ -33,66 +32,28 @@
 GalileoE5bPcpsAcquisitionFpga::GalileoE5bPcpsAcquisitionFpga(const ConfigurationInterface* configuration,
     const std::string& role,
     unsigned int in_streams,
-    unsigned int out_streams) : gnss_synchro_(nullptr),
-                                role_(role),
-                                doppler_center_(0),
-                                channel_(0),
-                                doppler_step_(0),
-                                in_streams_(in_streams),
-                                out_streams_(out_streams)
+    unsigned int out_streams)
+    : gnss_synchro_(nullptr),
+      role_(role),
+      doppler_center_(0),
+      channel_(0),
+      doppler_step_(0),
+      in_streams_(in_streams),
+      out_streams_(out_streams),
+      acq_pilot_(configuration->property(role + ".acquire_pilot", false)),
+      acq_iq_(configuration->property(role + ".acquire_iq", false))
 {
-    pcpsconf_fpga_t acq_parameters;
-    std::string default_dump_filename = "../data/acquisition.dat";
-
-    DLOG(INFO) << "Role " << role;
-
-    int64_t fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 32000000);
-    int64_t fs_in = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
-
-    acq_parameters.repeat_satellite = configuration->property(role + ".repeat_satellite", false);
-    DLOG(INFO) << role << " satellite repeat = " << acq_parameters.repeat_satellite;
-
-    uint32_t downsampling_factor = configuration->property(role + ".downsampling_factor", 1);
-    acq_parameters.downsampling_factor = downsampling_factor;
-    fs_in = fs_in / downsampling_factor;
-
-    acq_parameters.fs_in = fs_in;
-
-    doppler_max_ = configuration->property(role + ".doppler_max", 5000);
+    acq_parameters_.SetFromConfiguration(configuration, role_, fpga_buff_num, fpga_blk_exp, downsampling_factor_default, GALILEO_E5B_CODE_CHIP_RATE_CPS, GALILEO_E5B_CODE_LENGTH_CHIPS);
     if (FLAGS_doppler_max != 0)
         {
-            doppler_max_ = FLAGS_doppler_max;
+            acq_parameters_.doppler_max = FLAGS_doppler_max;
         }
-    acq_parameters.doppler_max = doppler_max_;
+    doppler_max_ = acq_parameters_.doppler_max;
+    doppler_step_ = static_cast<unsigned int>(acq_parameters_.doppler_step);
+    fs_in_ = acq_parameters_.fs_in;
 
-    acq_pilot_ = configuration->property(role + ".acquire_pilot", false);
-    acq_iq_ = configuration->property(role + ".acquire_iq", false);
-    if (acq_iq_)
-        {
-            acq_pilot_ = false;
-        }
-
-    auto code_length = static_cast<uint32_t>(std::round(static_cast<double>(fs_in) / GALILEO_E5B_CODE_CHIP_RATE_CPS * static_cast<double>(GALILEO_E5B_CODE_LENGTH_CHIPS)));
-    acq_parameters.code_length = code_length;
-
-    // The FPGA can only use FFT lengths that are a power of two.
-    float nbits = ceilf(log2f(static_cast<float>(code_length) * 2.0F));
-    uint32_t nsamples_total = pow(2, nbits);
-    uint32_t select_queue_Fpga = configuration->property(role + ".select_queue_Fpga", 1);
-    acq_parameters.select_queue_Fpga = select_queue_Fpga;
-
-    // UIO device file
-    std::string device_io_name;
-    // find the uio device file corresponding to the acquisition
-    if (find_uio_dev_file_name(device_io_name, acquisition_device_name, 0) < 0)
-        {
-            std::cout << "Cannot find the FPGA uio device file corresponding to device name " << acquisition_device_name << std::endl;
-            throw std::exception();
-        }
-    acq_parameters.device_name = device_io_name;
-
-    acq_parameters.samples_per_code = nsamples_total;
-    acq_parameters.excludelimit = static_cast<unsigned int>(1 + ceil((1.0 / GALILEO_E5B_CODE_CHIP_RATE_CPS) * static_cast<float>(fs_in)));
+    uint32_t code_length = acq_parameters_.code_length;
+    uint32_t nsamples_total = acq_parameters_.samples_per_code;
 
     // compute all the GALILEO E5b PRN Codes (this is done only once in the class constructor in order to avoid re-computing the PRN codes every time
     // a channel is assigned)
@@ -101,6 +62,11 @@ GalileoE5bPcpsAcquisitionFpga::GalileoE5bPcpsAcquisitionFpga(const Configuration
     volk_gnsssdr::vector<std::complex<float>> fft_codes_padded(nsamples_total);
     d_all_fft_codes_ = volk_gnsssdr::vector<uint32_t>(nsamples_total * GALILEO_E5B_NUMBER_OF_CODES);  // memory containing all the possible fft codes for PRN 0 to 32
 
+    if (acq_iq_)
+        {
+            acq_pilot_ = false;
+        }
+
     float max;  // temporary maxima search
     int32_t tmp;
     int32_t tmp2;
@@ -126,7 +92,7 @@ GalileoE5bPcpsAcquisitionFpga::GalileoE5bPcpsAcquisitionFpga(const Configuration
                     signal_[1] = 'I';
                 }
 
-            galileo_e5_b_code_gen_complex_sampled(code, PRN, signal_, fs_in, 0);
+            galileo_e5_b_code_gen_complex_sampled(code, PRN, signal_, fs_in_, 0);
 
             for (uint32_t s = code_length; s < 2 * code_length; s++)
                 {
@@ -167,16 +133,9 @@ GalileoE5bPcpsAcquisitionFpga::GalileoE5bPcpsAcquisitionFpga(const Configuration
                 }
         }
 
-    acq_parameters.all_fft_codes = d_all_fft_codes_.data();
+    acq_parameters_.all_fft_codes = d_all_fft_codes_.data();
 
-    // reference for the FPGA FFT-IFFT attenuation factor
-    acq_parameters.total_block_exp = configuration->property(role + ".total_block_exp", 13);
-
-    acq_parameters.num_doppler_bins_step2 = configuration->property(role + ".second_nbins", 4);
-    acq_parameters.doppler_step2 = configuration->property(role + ".second_doppler_step", static_cast<float>(125.0));
-    acq_parameters.make_2_steps = configuration->property(role + ".make_two_steps", false);
-    acq_parameters.max_num_acqs = configuration->property(role + ".max_num_acqs", 2);
-    acquisition_fpga_ = pcps_make_acquisition_fpga(acq_parameters);
+    acquisition_fpga_ = pcps_make_acquisition_fpga(acq_parameters_);
 
     if (in_streams_ > 1)
         {
