@@ -26,6 +26,7 @@
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>
 #include <memory>
 #include <string>
+#include <utility>
 
 /** \addtogroup Acquisition
  * \{ */
@@ -120,8 +121,8 @@ public:
      */
     inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm) override
     {
-        channel_fsm_ = channel_fsm;
-        acquisition_fpga_->set_channel_fsm(channel_fsm);
+        channel_fsm_ = std::move(channel_fsm);
+        acquisition_fpga_->set_channel_fsm(channel_fsm_);
     }
 
     /*!
@@ -187,9 +188,9 @@ public:
     void set_resampler_latency(uint32_t latency_samples __attribute__((unused))) override{};
 
 private:
-    static const uint32_t fpga_downsampling_factor = 1;  // downampling factor in the FPGA
-    static const uint32_t fpga_buff_num = 1;             // E5b band
-    static const uint32_t fpga_blk_exp = 13;             // default block exponent
+    static const uint32_t downsampling_factor_default = 1;
+    static const uint32_t fpga_buff_num = 1;  // E5b band
+    static const uint32_t fpga_blk_exp = 13;  // default block exponent
 
     // the following flags are FPGA-specific and they are using arrange the values of the fft of the local code in the way the FPGA
     // expects. This arrangement is done in the initialisation to avoid consuming unnecessary clock cycles during tracking.
