@@ -30,28 +30,33 @@ GpsL1CaPcpsAssistedAcquisition::GpsL1CaPcpsAssistedAcquisition(
     const ConfigurationInterface* configuration,
     const std::string& role,
     unsigned int in_streams,
-    unsigned int out_streams) : role_(role),
-                                in_streams_(in_streams),
-                                out_streams_(out_streams)
+    unsigned int out_streams)
+    : role_(role),
+      gnss_synchro_(nullptr),
+      item_size_(sizeof(gr_complex)),
+      threshold_(0.0),
+      doppler_max_(configuration->property(role + ".doppler_max", 5000)),
+      max_dwells_(configuration->property(role + ".max_dwells", 1)),
+      channel_(0),
+      doppler_step_(0),
+      sampled_ms_(configuration->property(role + ".coherent_integration_time_ms", 1)),
+      in_streams_(in_streams),
+      out_streams_(out_streams),
+      dump_(configuration->property(role + ".dump", false))
 {
     const std::string default_item_type("gr_complex");
     std::string default_dump_filename = "./data/acquisition.dat";
-
-    DLOG(INFO) << "role " << role;
-
-    item_type_ = configuration->property(role + ".item_type", default_item_type);
+    dump_filename_ = configuration->property(role_ + ".dump_filename", std::move(default_dump_filename));
+    item_type_ = configuration->property(role_ + ".item_type", default_item_type);
     int64_t fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000);
     fs_in_ = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
-    dump_ = configuration->property(role + ".dump", false);
-    doppler_max_ = configuration->property(role + ".doppler_max", 5000);
+
     if (FLAGS_doppler_max != 0)
         {
             doppler_max_ = FLAGS_doppler_max;
         }
-    doppler_min_ = configuration->property(role + ".doppler_min", -doppler_max_);
-    sampled_ms_ = configuration->property(role + ".coherent_integration_time_ms", 1);
-    max_dwells_ = configuration->property(role + ".max_dwells", 1);
-    dump_filename_ = configuration->property(role + ".dump_filename", default_dump_filename);
+    doppler_min_ = configuration->property(role_ + ".doppler_min", -doppler_max_);
+
     bool enable_monitor_output = configuration->property("AcquisitionMonitor.enable_monitor", false);
 
     // --- Find number of samples per spreading code -------------------------
@@ -59,24 +64,20 @@ GpsL1CaPcpsAssistedAcquisition::GpsL1CaPcpsAssistedAcquisition(
 
     code_ = std::vector<std::complex<float>>(vector_length_);
 
+    DLOG(INFO) << "role " << role_;
     if (item_type_ == "gr_complex")
         {
-            item_size_ = sizeof(gr_complex);
             acquisition_cc_ = pcps_make_assisted_acquisition_cc(max_dwells_, sampled_ms_,
                 doppler_max_, doppler_min_, fs_in_, vector_length_,
                 dump_, dump_filename_, enable_monitor_output);
         }
     else
         {
-            item_size_ = sizeof(gr_complex);
+            item_size_ = 0;
+            acquisition_cc_ = nullptr;
             LOG(WARNING) << item_type_ << " unknown acquisition item type";
         }
 
-    channel_ = 0;
-    threshold_ = 0.0;
-    doppler_step_ = 0;
-    gnss_synchro_ = nullptr;
-
     if (in_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one input stream";
