@@ -33,10 +33,9 @@
 #include <pmt/pmt_sugar.h>  // for mp
 #include <volk/volk.h>
 #include <volk_gnsssdr/volk_gnsssdr.h>
-#include <algorithm>  // for fill_n, min
+#include <algorithm>  // for std::fill_n, std::min, std::copy
 #include <array>
-#include <cmath>    // for floor, fmod, rint, ceil
-#include <cstring>  // for memcpy
+#include <cmath>  // for floor, fmod, rint, ceil
 #include <iostream>
 #include <map>
 
@@ -189,18 +188,18 @@ void pcps_acquisition::set_local_code(std::complex<float>* code)
         {
             const int32_t offset = d_fft_size / 2;
             std::fill_n(d_fft_if->get_inbuf(), offset, gr_complex(0.0, 0.0));
-            memcpy(d_fft_if->get_inbuf() + offset, code, sizeof(gr_complex) * offset);
+            std::copy(code, code + offset, d_fft_if->get_inbuf() + offset);
         }
     else
         {
             if (d_acq_parameters.sampled_ms == d_acq_parameters.ms_per_code)
                 {
-                    memcpy(d_fft_if->get_inbuf(), code, sizeof(gr_complex) * d_consumed_samples);
+                    std::copy(code, code + d_consumed_samples, d_fft_if->get_inbuf());
                 }
             else
                 {
                     std::fill_n(d_fft_if->get_inbuf(), d_fft_size - d_consumed_samples, gr_complex(0.0, 0.0));
-                    memcpy(d_fft_if->get_inbuf() + d_consumed_samples, code, sizeof(gr_complex) * d_consumed_samples);
+                    std::copy(code, code + d_consumed_samples, d_fft_if->get_inbuf() + d_consumed_samples);
                 }
         }
 
@@ -259,7 +258,7 @@ void pcps_acquisition::init()
     d_mag = 0.0;
     d_input_power = 0.0;
 
-    d_num_doppler_bins = static_cast<uint32_t>(std::ceil(static_cast<double>(static_cast<int32_t>(d_acq_parameters.doppler_max) - static_cast<int32_t>(-d_acq_parameters.doppler_max)) / static_cast<double>(d_doppler_step)));
+    d_num_doppler_bins = static_cast<uint32_t>(std::ceil(static_cast<double>(2 * d_acq_parameters.doppler_max) / static_cast<double>(d_doppler_step)));
 
     // Create the carrier Doppler wipeoff signals
     if (d_grid_doppler_wipeoffs.empty())
@@ -577,7 +576,7 @@ float pcps_acquisition::first_vs_second_peak_statistic(uint32_t& indext, int32_t
         }
 
     int32_t idx = excludeRangeIndex1;
-    memcpy(d_tmp_buffer.data(), d_magnitude_grid[index_doppler].data(), d_fft_size * sizeof(float));
+    std::copy(d_magnitude_grid[index_doppler].data(), d_magnitude_grid[index_doppler].data() + d_fft_size, d_tmp_buffer.data());
     do
         {
             d_tmp_buffer[idx] = 0.0;
@@ -610,7 +609,7 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
         {
             volk_gnsssdr_16ic_convert_32fc(d_data_buffer.data(), d_data_buffer_sc.data(), d_consumed_samples);
         }
-    memcpy(d_input_signal.data(), d_data_buffer.data(), d_consumed_samples * sizeof(gr_complex));
+    std::copy(d_data_buffer.data(), d_data_buffer.data() + d_consumed_samples, d_input_signal.data());
     if (d_fft_size > d_consumed_samples)
         {
             for (uint32_t i = d_consumed_samples; i < d_fft_size; i++)
@@ -667,7 +666,7 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                     // Record results to file if required
                     if (d_dump and d_channel == d_dump_channel)
                         {
-                            memcpy(d_grid.colptr(doppler_index), d_magnitude_grid[doppler_index].data(), sizeof(float) * effective_fft_size);
+                            std::copy(d_magnitude_grid[doppler_index].data(), d_magnitude_grid[doppler_index].data() + effective_fft_size, d_grid.colptr(doppler_index));
                         }
                 }
 
@@ -725,7 +724,7 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                     // Record results to file if required
                     if (d_dump and d_channel == d_dump_channel)
                         {
-                            memcpy(d_narrow_grid.colptr(doppler_index), d_magnitude_grid[doppler_index].data(), sizeof(float) * effective_fft_size);
+                            std::copy(d_magnitude_grid[doppler_index].data(), d_magnitude_grid[doppler_index].data() + effective_fft_size, d_narrow_grid.colptr(doppler_index));
                         }
                 }
             // Compute the test statistic
@@ -777,6 +776,8 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                             else
                                 {
                                     d_step_two = true;  // Clear input buffer and make small grid acquisition
+                                    d_doppler_center_step_two = static_cast<float>(d_gnss_synchro->Acq_doppler_hz);
+                                    update_grid_doppler_wipeoffs_step2();
                                     d_num_noncoherent_integrations_counter = 0;
                                     d_positive_acq = 0;
                                     d_state = 0;
@@ -827,6 +828,8 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                             else
                                 {
                                     d_step_two = true;  // Clear input buffer and make small grid acquisition
+                                    d_doppler_center_step_two = static_cast<float>(d_gnss_synchro->Acq_doppler_hz);
+                                    update_grid_doppler_wipeoffs_step2();
                                     d_num_noncoherent_integrations_counter = 0U;
                                     d_state = 0;
                                 }
@@ -868,6 +871,7 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
 // Called by gnuradio to enable drivers, etc for i/o devices.
 bool pcps_acquisition::start()
 {
+    gr::thread::scoped_lock lk(d_setlock);
     d_sample_counter = 0ULL;
     calculate_threshold();
     return true;
@@ -910,15 +914,15 @@ int pcps_acquisition::general_work(int noutput_items __attribute__((unused)),
     gr::thread::scoped_lock lk(d_setlock);
     if (!d_active or d_worker_active)
         {
-            if (!d_acq_parameters.blocking_on_standby)
+            // do not consume samples while performing a non-coherent integration
+            bool consume_samples = ((!d_active) || (d_worker_active && (d_num_noncoherent_integrations_counter == d_acq_parameters.max_dwells)));
+            if ((!d_acq_parameters.blocking_on_standby) && consume_samples)
                 {
                     d_sample_counter += static_cast<uint64_t>(ninput_items[0]);
                     consume_each(ninput_items[0]);
                 }
             if (d_step_two)
                 {
-                    d_doppler_center_step_two = static_cast<float>(d_gnss_synchro->Acq_doppler_hz);
-                    update_grid_doppler_wipeoffs_step2();
                     d_state = 0;
                     d_active = true;
                 }
@@ -958,7 +962,7 @@ int pcps_acquisition::general_work(int noutput_items __attribute__((unused)),
                             {
                                 buff_increment = d_consumed_samples - d_buffer_count;
                             }
-                        memcpy(&d_data_buffer_sc[d_buffer_count], in, sizeof(lv_16sc_t) * buff_increment);
+                        std::copy(in, in + buff_increment, d_data_buffer_sc.begin() + d_buffer_count);
                     }
                 else
                     {
@@ -971,7 +975,7 @@ int pcps_acquisition::general_work(int noutput_items __attribute__((unused)),
                             {
                                 buff_increment = d_consumed_samples - d_buffer_count;
                             }
-                        memcpy(&d_data_buffer[d_buffer_count], in, sizeof(gr_complex) * buff_increment);
+                        std::copy(in, in + buff_increment, d_data_buffer.begin() + d_buffer_count);
                     }
 
                 // If buffer will be full in next iteration
@@ -1014,7 +1018,7 @@ int pcps_acquisition::general_work(int noutput_items __attribute__((unused)),
                         {
                             Gnss_Synchro current_synchro_data = d_monitor_queue.front();
                             d_monitor_queue.pop();
-                            *out[i] = current_synchro_data;
+                            *out[i] = std::move(current_synchro_data);
                         }
                     return num_gnss_synchro_objects;
                 }
