@@ -21,8 +21,14 @@
 #include <volk/volk.h>
 
 
-IbyteToCbyte::IbyteToCbyte(const ConfigurationInterface* configuration, const std::string& role,
-    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
+IbyteToCbyte::IbyteToCbyte(const ConfigurationInterface* configuration,
+    const std::string& role,
+    unsigned int in_streams,
+    unsigned int out_streams) : role_(role),
+                                in_streams_(in_streams),
+                                out_streams_(out_streams),
+                                inverted_spectrum(configuration->property(role + ".inverted_spectrum", false)),
+                                dump_(configuration->property(role + ".dump", false))
 {
     const std::string default_input_item_type("byte");
     const std::string default_output_item_type("lv_8sc_t");
@@ -31,12 +37,7 @@ IbyteToCbyte::IbyteToCbyte(const ConfigurationInterface* configuration, const st
     DLOG(INFO) << "role " << role_;
 
     input_item_type_ = configuration->property(role_ + ".input_item_type", default_input_item_type);
-
-    dump_ = configuration->property(role_ + ".dump", false);
     dump_filename_ = configuration->property(role_ + ".dump_filename", default_dump_filename);
-    inverted_spectrum = configuration->property(role + ".inverted_spectrum", false);
-
-    const size_t item_size = sizeof(lv_8sc_t);
 
     ibyte_to_cbyte_ = make_interleaved_byte_to_complex_byte();
 
@@ -45,6 +46,7 @@ IbyteToCbyte::IbyteToCbyte(const ConfigurationInterface* configuration, const st
     if (dump_)
         {
             DLOG(INFO) << "Dumping output into file " << dump_filename_;
+            const size_t item_size = sizeof(lv_8sc_t);
             file_sink_ = gr::blocks::file_sink::make(item_size, dump_filename_.c_str());
         }
     if (inverted_spectrum)
