@@ -32,7 +32,7 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(const ConfigurationInterface* configu
     : role_(std::move(role)),
       in_streams_(in_streams),
       out_streams_(out_streams),
-      dump_(configuration->property(role + ".dump", false))
+      dump_(configuration->property(role_ + ".dump", false))
 {
     const std::string default_input_item_type("gr_complex");
     const std::string default_output_item_type("gr_complex");
