@@ -19,8 +19,8 @@
 #define GNSS_SDR_NOTCH_CC_H
 
 #include "gnss_block_interface.h"
+#include "gnss_sdr_fft.h"
 #include <gnuradio/block.h>
-#include <gnuradio/fft/fft.h>
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>  // for volk_gnsssdr::vector
 #include <cstdint>
 #include <memory>
@@ -57,11 +57,8 @@ public:
 private:
     friend notch_sptr make_notch_filter(float pfa, float p_c_factor, int32_t length, int32_t n_segments_est, int32_t n_segments_reset);
     Notch(float pfa, float p_c_factor, int32_t length, int32_t n_segments_est, int32_t n_segments_reset);
-#if GNURADIO_FFT_USES_TEMPLATES
-    std::unique_ptr<gr::fft::fft_complex_fwd> d_fft_;
-#else
-    std::unique_ptr<gr::fft::fft_complex> d_fft_;
-#endif
+
+    std::unique_ptr<gnss_fft_complex_fwd> d_fft_;
     volk_gnsssdr::vector<gr_complex> c_samples_;
     volk_gnsssdr::vector<float> angle_;
     volk_gnsssdr::vector<float> power_spect_;
