@@ -62,6 +62,24 @@
 #include <cstddef>
 #include <string>
 
+#if HAS_STD_FILESYSTEM
+#include <system_error>
+namespace errorlib = std;
+#if HAS_STD_FILESYSTEM_EXPERIMENTAL
+#include <experimental/filesystem>
+namespace fs = std::experimental::filesystem;
+#else
+#include <filesystem>
+namespace fs = std::filesystem;
+#endif
+#else
+#include <boost/filesystem/operations.hpp>   // for create_directories, exists
+#include <boost/filesystem/path.hpp>         // for path, operator<<
+#include <boost/filesystem/path_traits.hpp>  // for filesystem
+#include <boost/system/error_code.hpp>       // for error_code
+namespace fs = boost::filesystem;
+namespace errorlib = boost::system;
+#endif
 
 /* coordinate rotation matrix ------------------------------------------------*/
 #define Rx(t, X)                                     \
@@ -102,7 +120,7 @@ void fatalerr(const char *format, ...);
 int satno(int sys, int prn);
 int satsys(int sat, int *prn);
 int satid2no(const char *id);
-void satno2id(int sat, char *id);
+std::string satno2id(int sat);
 int satexclude(int sat, int svh, const prcopt_t *opt);
 int testsnr(int base, int freq, double el, double snr, const snrmask_t *mask);
 unsigned char obs2code(const char *obs, int *freq);
@@ -229,12 +247,9 @@ void traceobs(int level, const obsd_t *obs, int n);
 // void traceb  (int level, const unsigned char *p, int n);
 
 int execcmd(const char *cmd);
-void createdir(const char *path);
-int repstr(char *str, const char *pat, const char *rep);
-int reppath(const char *path, char *rpath, gtime_t time, const char *rov,
+void createdir(fs::path const &path);
+int reppath(std::string const &path, std::string &rpath, gtime_t time, const char *rov,
     const char *base);
-int reppaths(const char *path, char *rpath[], int nmax, gtime_t ts,
-    gtime_t te, const char *rov, const char *base);
 double satwavelen(int sat, int frq, const nav_t *nav);
 double geodist(const double *rs, const double *rr, double *e);
 double satazel(const double *pos, const double *e, double *azel);
