@@ -75,6 +75,7 @@ typedef struct
     int amx_bf16 : 1;
     int amx_tile : 1;
     int amx_int8 : 1;
+    int amx_fp16 : 1;
 
     int pclmulqdq : 1;
     int smx : 1;
@@ -96,7 +97,10 @@ typedef struct
     int fz_rep_movsb : 1;        // Fast zero-length REP MOVSB
     int fs_rep_stosb : 1;        // Fast short REP STOSB
     int fs_rep_cmpsb_scasb : 1;  // Fast short REP CMPSB/SCASB
-                                 // Make sure to update X86FeaturesEnum below if you add a field here.
+
+    int lam : 1;  // Intel Linear Address Mask
+    int uai : 1;  // AMD Upper Address Ignore
+                  // Make sure to update X86FeaturesEnum below if you add a field here.
 } X86Features;
 
 typedef struct
@@ -114,7 +118,6 @@ X86Info GetX86Info(void);
 
 // Returns cache hierarchy informations.
 // Can call cpuid multiple times.
-// Only works on Intel CPU at the moment.
 CacheInfo GetX86CacheInfo(void);
 
 typedef enum
@@ -244,6 +247,7 @@ typedef enum
     X86_AMX_BF16,
     X86_AMX_TILE,
     X86_AMX_INT8,
+    X86_AMX_FP16,
     X86_PCLMULQDQ,
     X86_SMX,
     X86_SGX,
@@ -263,6 +267,8 @@ typedef enum
     X86_FZ_REP_MOVSB,
     X86_FS_REP_STOSB,
     X86_FS_REP_CMPSB_SCASB,
+    X86_LAM,
+    X86_UAI,
     X86_LAST_,
 } X86FeaturesEnum;
 
