@@ -27,6 +27,8 @@
 #include "cpuinfo_s390x.h"
 #elif defined(CPU_FEATURES_ARCH_RISCV)
 #include "cpuinfo_riscv.h"
+#elif defined(CPU_FEATURES_ARCH_LOONGARCH)
+#include "cpuinfo_loongarch.h"
 #endif
 
 // Design principles
@@ -217,11 +219,14 @@ DEFINE_ADD_FLAGS(GetMipsFeaturesEnumValue, GetMipsFeaturesEnumName,
 DEFINE_ADD_FLAGS(GetPPCFeaturesEnumValue, GetPPCFeaturesEnumName, PPCFeatures,
     PPC_LAST_)
 #elif defined(CPU_FEATURES_ARCH_S390X)
-DEFINE_ADD_FLAGS(GetS390XFeaturesEnumValue, GetS390XFeaturesEnumName, S390XFeatures,
-    S390X_LAST_)
+DEFINE_ADD_FLAGS(GetS390XFeaturesEnumValue, GetS390XFeaturesEnumName,
+    S390XFeatures, S390X_LAST_)
 #elif defined(CPU_FEATURES_ARCH_RISCV)
-DEFINE_ADD_FLAGS(GetRiscvFeaturesEnumValue, GetRiscvFeaturesEnumName, RiscvFeatures,
-    RISCV_LAST_)
+DEFINE_ADD_FLAGS(GetRiscvFeaturesEnumValue, GetRiscvFeaturesEnumName,
+    RiscvFeatures, RISCV_LAST_)
+#elif defined(CPU_FEATURES_ARCH_LOONGARCH)
+DEFINE_ADD_FLAGS(GetLoongArchFeaturesEnumValue, GetLoongArchFeaturesEnumName,
+    LoongArchFeatures, LOONGARCH_LAST_)
 #endif
 
 // Prints a json string with characters escaping.
@@ -458,6 +463,10 @@ static Node* CreateTree(void)
     AddMapEntry(root, "vendor", CreateString(info.vendor));
     AddMapEntry(root, "microarchitecture", CreateString(info.uarch));
     AddFlags(root, &info.features);
+#elif defined(CPU_FEATURES_ARCH_LOONGARCH)
+    const LoongArchInfo info = GetLoongArchInfo();
+    AddMapEntry(root, "arch", CreateString("loongarch"));
+    AddFlags(root, &info.features);
 #endif
     return root;
 }
@@ -489,4 +498,4 @@ int main(int argc, char** argv)
         printTextRoot(root);
     putchar('\n');
     return EXIT_SUCCESS;
-}
+}
\ No newline at end of file
