@@ -22,7 +22,6 @@
 #include <random>                              // for random_device, default_random_engine, uniform_real_distribution
 #include <vector>                              // for vector
 
-
 template <typename T>
 void random_values(T *buf, unsigned int n, std::default_random_engine &e1)
 {
@@ -33,59 +32,94 @@ void random_values(T *buf, unsigned int n, std::default_random_engine &e1)
 
 void load_random_data(void *data, volk_gnsssdr_type_t type, unsigned int n)
 {
-    std::random_device r;
-    std::default_random_engine e1(r());
-    std::default_random_engine e2(r());
+    std::random_device rnd_device;
+    std::default_random_engine rnd_engine(rnd_device());
 
     if (type.is_complex) n *= 2;
 
     if (type.is_float)
         {
             if (type.size == 8)
-                random_values<double>((double *)data, n, e1);
+                random_values<double>((double *)data, n, rnd_engine);
             else
-                random_values<float>((float *)data, n, e1);
+                random_values<float>((float *)data, n, rnd_engine);
         }
     else
         {
-            float int_max = float(uint64_t(2) << (type.size * 8));
-            if (type.is_signed) int_max /= 2.0;
-            std::uniform_real_distribution<float> uniform_dist(-int_max, int_max);
-            for (unsigned int i = 0; i < n; i++)
+            switch (type.size)
                 {
-                    float scaled_rand = uniform_dist(e2);
-
-                    switch (type.size)
+                case 8:
+                    if (type.is_signed)
                         {
-                        case 8:
-                            if (type.is_signed)
-                                ((int64_t *)data)[i] = (int64_t)scaled_rand;
-                            else
-                                ((uint64_t *)data)[i] = (uint64_t)scaled_rand;
-                            break;
-                        case 4:
-                            if (type.is_signed)
-                                ((int32_t *)data)[i] = (int32_t)scaled_rand;
-                            else
-                                ((uint32_t *)data)[i] = (uint32_t)scaled_rand;
-                            break;
-                        case 2:
-                            // 16 bit multiplication saturates very fast
-                            // we produce here only 3 bits input range
-                            if (type.is_signed)
-                                ((int16_t *)data)[i] = (int16_t)((int16_t)scaled_rand % 8);
-                            else
-                                ((uint16_t *)data)[i] = (uint16_t)(int16_t)((int16_t)scaled_rand % 8);
-                            break;
-                        case 1:
-                            if (type.is_signed)
-                                ((int8_t *)data)[i] = (int8_t)scaled_rand;
-                            else
-                                ((uint8_t *)data)[i] = (uint8_t)scaled_rand;
-                            break;
-                        default:
-                            throw "load_random_data: no support for data size > 8 or < 1";  // no shenanigans here
+                            std::uniform_int_distribution<int64_t> uniform_dist(
+                                std::numeric_limits<int64_t>::min(),
+                                std::numeric_limits<int64_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((int64_t *)data)[i] = uniform_dist(rnd_engine);
                         }
+                    else
+                        {
+                            std::uniform_int_distribution<uint64_t> uniform_dist(
+                                std::numeric_limits<uint64_t>::min(),
+                                std::numeric_limits<uint64_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((uint64_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    break;
+                case 4:
+                    if (type.is_signed)
+                        {
+                            std::uniform_int_distribution<int32_t> uniform_dist(
+                                std::numeric_limits<int32_t>::min(),
+                                std::numeric_limits<int32_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((int32_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    else
+                        {
+                            std::uniform_int_distribution<uint32_t> uniform_dist(
+                                std::numeric_limits<uint32_t>::min(),
+                                std::numeric_limits<uint32_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((uint32_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    break;
+                case 2:
+                    if (type.is_signed)
+                        {
+                            std::uniform_int_distribution<int16_t> uniform_dist(-7, 7);
+                            for (unsigned int i = 0; i < n; i++)
+                                ((int16_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    else
+                        {
+                            std::uniform_int_distribution<uint16_t> uniform_dist(
+                                std::numeric_limits<uint16_t>::min(),
+                                std::numeric_limits<uint16_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((uint16_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    break;
+                case 1:
+                    if (type.is_signed)
+                        {
+                            std::uniform_int_distribution<int16_t> uniform_dist(
+                                std::numeric_limits<int8_t>::min(),
+                                std::numeric_limits<int8_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((int8_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    else
+                        {
+                            std::uniform_int_distribution<uint16_t> uniform_dist(
+                                std::numeric_limits<uint8_t>::min(),
+                                std::numeric_limits<uint8_t>::max());
+                            for (unsigned int i = 0; i < n; i++)
+                                ((uint8_t *)data)[i] = uniform_dist(rnd_engine);
+                        }
+                    break;
+                default:
+                    throw "load_random_data: no support for data size > 8 or < 1";  // no shenanigans here
                 }
         }
 }
@@ -449,12 +483,12 @@ bool icompare(t *in1, t *in2, unsigned int vlen, unsigned int tol)
     int print_max_errs = 10;
     for (unsigned int i = 0; i < vlen; i++)
         {
-            if (((unsigned int)abs(int(((t *)(in1))[i]) - int(((t *)(in2))[i]))) > tol)
+            if (((uint64_t)abs(int64_t(((t *)(in1))[i]) - int64_t(((t *)(in2))[i]))) > tol)
                 {
                     fail = true;
                     if (print_max_errs-- > 0)
                         {
-                            std::cout << "offset " << i << " in1: " << static_cast<int>(t(((t *)(in1))[i])) << " in2: " << static_cast<int>(t(((t *)(in2))[i]));
+                            std::cout << "offset " << i << " in1: " << static_cast<int64_t>(t(((t *)(in1))[i])) << " in2: " << static_cast<int64_t>(t(((t *)(in2))[i]));
                             std::cout << " tolerance was: " << tol << '\n';
                         }
                 }
@@ -911,14 +945,14 @@ bool run_volk_gnsssdr_tests(volk_gnsssdr_func_desc_t desc,
 
     if (puppet_master_name == "NULL")
         {
-            results->back().config_name = name;
+            results->back().config_name = std::move(name);
         }
     else
         {
-            results->back().config_name = puppet_master_name;
+            results->back().config_name = std::move(puppet_master_name);
         }
-    results->back().best_arch_a = best_arch_a;
-    results->back().best_arch_u = best_arch_u;
+    results->back().best_arch_a = std::move(best_arch_a);
+    results->back().best_arch_u = std::move(best_arch_u);
 
     return fail_global;
 }
