@@ -23,11 +23,7 @@
 
 #include "concurrent_queue.h"
 #include "fpga_buffer_monitor.h"
-#if INTPTR_MAX == INT64_MAX  // 64-bit processor architecture
 #include "fpga_dma-proxy.h"
-#else
-#include "fpga_ezdma.h"
-#endif
 #include "fpga_dynamic_bit_selection.h"
 #include "fpga_switch.h"
 #include "gnss_block_interface.h"
@@ -118,7 +114,6 @@ private:
 
     Concurrent_Queue<pmt::pmt_t> *queue_;
 
-    // Front-end settings
     std::string gain_mode_rx1_;
     std::string gain_mode_rx2_;
     std::string rf_port_select_;
@@ -130,30 +125,31 @@ private:
 
     double rf_gain_rx1_;
     double rf_gain_rx2_;
+    double scale_dds_dbfs_;
+    double phase_dds_deg_;
+    double tx_attenuation_db_;
+
     uint64_t freq0_;  // frequency of local oscillator for ADRV9361-A 0
     uint64_t freq1_;  // frequency of local oscillator for ADRV9361-B (if present)
     uint64_t sample_rate_;
     uint64_t bandwidth_;
     uint64_t samples_to_skip_;
     int64_t samples_;
-    float Fpass_;
-    float Fstop_;
-    uint32_t num_freq_bands_;
-    uint32_t dma_buff_offset_pos_;
-
-    // DDS configuration for LO generation for external mixer
-    double scale_dds_dbfs_;
-    double phase_dds_deg_;
-    double tx_attenuation_db_;
     uint64_t freq_dds_tx_hz_;
     uint64_t freq_rf_tx_hz_;
     uint64_t tx_bandwidth_;
-    size_t item_size_;
+
+    float Fpass_;
+    float Fstop_;
+    uint32_t num_input_files_;
+    uint32_t dma_buff_offset_pos_;
     uint32_t in_stream_;
     uint32_t out_stream_;
     int32_t switch_position_;
-    bool enable_dds_lo_;
 
+    size_t item_size_;
+
+    bool enable_dds_lo_;
     bool filter_auto_;
     bool quadrature_;
     bool rf_dc_;
