@@ -40,7 +40,7 @@ NsrFileSignalSource::NsrFileSignalSource(const ConfigurationInterface* configura
 std::tuple<size_t, bool> NsrFileSignalSource::itemTypeToSize()
 {
     auto is_complex = false;
-    auto item_size = size_t(sizeof(char));  // default
+    auto item_size = sizeof(char);  // default
 
     if (item_type() == "byte")
         {
