@@ -19,10 +19,14 @@
 #ifndef GNSS_SDR_PLUTOSDR_SIGNAL_SOURCE_H
 #define GNSS_SDR_PLUTOSDR_SIGNAL_SOURCE_H
 
-#include "gnss_block_interface.h"
+#include "signal_source_base.h"
 #include <gnuradio/blocks/file_sink.h>
 #if GRIIO_INCLUDE_HAS_GNURADIO
+#if GR_IIO_TEMPLATIZED_API
+#include <gnuradio/iio/fmcomms2_source.h>
+#else
 #include <gnuradio/iio/pluto_source.h>
+#endif
 #else
 #include <iio/pluto_source.h>
 #endif
@@ -42,7 +46,7 @@ class ConfigurationInterface;
 
 /*!
  */
-class PlutosdrSignalSource : public GNSSBlockInterface
+class PlutosdrSignalSource : public SignalSourceBase
 {
 public:
     PlutosdrSignalSource(const ConfigurationInterface* configuration,
@@ -51,18 +55,6 @@ public:
 
     ~PlutosdrSignalSource() = default;
 
-    std::string role() override
-    {
-        return role_;
-    }
-
-    /*!
-     * \brief Returns "Plutosdr_Signal_Source"
-     */
-    std::string implementation() override
-    {
-        return "Plutosdr_Signal_Source";
-    }
     size_t item_size() override
     {
         return item_size_;
@@ -74,12 +66,16 @@ public:
     gr::basic_block_sptr get_right_block() override;
 
 private:
+    const std::string default_gain_mode = std::string("slow_attack");
+#if GR_IIO_TEMPLATIZED_API
+    gr::iio::fmcomms2_source<gr_complex>::sptr plutosdr_source_;
+#else
     gr::iio::pluto_source::sptr plutosdr_source_;
+#endif
 
     gnss_shared_ptr<gr::block> valve_;
     gr::blocks::file_sink::sptr file_sink_;
 
-    std::string role_;
     std::string dump_filename_;
 
     // Front-end settings
