@@ -43,7 +43,7 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(
 std::tuple<size_t, bool> TwoBitCpxFileSignalSource::itemTypeToSize()
 {
     auto is_complex = false;
-    auto item_size = size_t(sizeof(char));  // default
+    auto item_size = sizeof(char);  // default
 
     if (item_type() == "byte")
         {
