@@ -50,8 +50,6 @@ public:
         unsigned int in_streams,
         unsigned int out_streams);
 
-    ~GalileoE5bTelemetryDecoder() = default;
-
     /*!
      * \brief Returns "Galileo_E5b_Telemetry_Decoder"
      */
@@ -104,7 +102,6 @@ private:
     Gnss_Satellite satellite_;
     Tlm_Conf tlm_parameters_;
     std::string role_;
-    int channel_;
     unsigned int in_streams_;
     unsigned int out_streams_;
 };
