@@ -44,7 +44,7 @@ bool Tlm_CRC_Stats::set_channel(int32_t channel)
         {
             std::string dump_filename_ = d_dump_crc_stats_filename.substr(d_dump_crc_stats_filename.find_last_of('/') + 1);
             dump_path = d_dump_crc_stats_filename.substr(0, d_dump_crc_stats_filename.find_last_of('/'));
-            d_dump_crc_stats_filename = dump_filename_;
+            d_dump_crc_stats_filename = std::move(dump_filename_);
         }
     else
         {
