@@ -25,19 +25,26 @@
 #include "uio_fpga.h"
 #include <glog/logging.h>
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>
+#include <algorithm>
 #include <array>
 
 GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
-    const ConfigurationInterface *configuration, const std::string &role,
-    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
+    const ConfigurationInterface *configuration,
+    const std::string &role,
+    unsigned int in_streams,
+    unsigned int out_streams)
+    : role_(role),
+      data_codes_ptr_(nullptr),
+      channel_(0),
+      in_streams_(in_streams),
+      out_streams_(out_streams)
 {
     Dll_Pll_Conf_Fpga trk_params_fpga = Dll_Pll_Conf_Fpga();
-    DLOG(INFO) << "role " << role;
-    trk_params_fpga.SetFromConfiguration(configuration, role);
+    trk_params_fpga.SetFromConfiguration(configuration, role_);
 
     const auto vector_length = static_cast<int32_t>(std::round(trk_params_fpga.fs_in / (GALILEO_E5A_CODE_CHIP_RATE_CPS / GALILEO_E5A_CODE_LENGTH_CHIPS)));
     trk_params_fpga.vector_length = vector_length;
-    d_track_pilot = trk_params_fpga.track_pilot;
+    track_pilot_ = trk_params_fpga.track_pilot;
     if (trk_params_fpga.extend_correlation_symbols < 1)
         {
             trk_params_fpga.extend_correlation_symbols = 1;
@@ -53,13 +60,11 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
             std::cout << TEXT_RED << "WARNING: Galileo E5a. PLL or DLL narrow tracking bandwidth is higher than wide tracking one" << TEXT_RESET << '\n';
         }
     trk_params_fpga.system = 'E';
-    const std::array<char, 3> sig_{'5', 'X', '\0'};
-    std::memcpy(trk_params_fpga.signal, sig_.data(), 3);
-
-    d_data_codes = nullptr;
+    const std::array<char, 3> sig{'5', 'X', '\0'};
+    std::copy_n(sig.data(), 3, trk_params_fpga.signal);
 
     // UIO device file
-    device_name = configuration->property(role + ".devicename", default_device_name_Galileo_E5a);
+    device_name_ = configuration->property(role_ + ".devicename", default_device_name_Galileo_E5a);
 
     // compute the number of tracking channels that have already been instantiated. The order in which
     // GNSS-SDR instantiates the tracking channels i L1, L2, L5, E1, E5a
@@ -70,12 +75,12 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
 
     uint32_t num_prev_assigned_ch_1C = configuration->property("Channels_1C.count", 0);
     uint32_t num_prev_assigned_ch_2S = 0;
-    if (configuration->property("Tracking_2S.devicename", std::string("")) != device_name)
+    if (configuration->property("Tracking_2S.devicename", std::string("")) != device_name_)
         {
             num_prev_assigned_ch_2S = configuration->property("Channels_2S.count", 0);
         }
     uint32_t num_prev_assigned_ch_1B = configuration->property("Channels_1B.count", 0);
-    num_prev_assigned_ch = num_prev_assigned_ch_1C + num_prev_assigned_ch_2S + num_prev_assigned_ch_1B;
+    num_prev_assigned_ch_ = num_prev_assigned_ch_1C + num_prev_assigned_ch_2S + num_prev_assigned_ch_1B;
 
     // ################# PRE-COMPUTE ALL THE CODES #################
     uint32_t code_samples_per_chip = 1;
@@ -83,11 +88,11 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
 
     volk_gnsssdr::vector<gr_complex> aux_code(code_length_chips * code_samples_per_chip, gr_complex(0.0, 0.0));
 
-    d_ca_codes = static_cast<int32_t *>(volk_gnsssdr_malloc(static_cast<int32_t>(code_length_chips) * code_samples_per_chip * GALILEO_E5A_NUMBER_OF_CODES * sizeof(int32_t), volk_gnsssdr_get_alignment()));
+    prn_codes_ptr_ = static_cast<int32_t *>(volk_gnsssdr_malloc(static_cast<int32_t>(code_length_chips) * code_samples_per_chip * GALILEO_E5A_NUMBER_OF_CODES * sizeof(int32_t), volk_gnsssdr_get_alignment()));
 
     if (trk_params_fpga.track_pilot)
         {
-            d_data_codes = static_cast<int32_t *>(volk_gnsssdr_malloc((static_cast<uint32_t>(code_length_chips)) * code_samples_per_chip * GALILEO_E5A_NUMBER_OF_CODES * sizeof(int32_t), volk_gnsssdr_get_alignment()));
+            data_codes_ptr_ = static_cast<int32_t *>(volk_gnsssdr_malloc((static_cast<uint32_t>(code_length_chips)) * code_samples_per_chip * GALILEO_E5A_NUMBER_OF_CODES * sizeof(int32_t), volk_gnsssdr_get_alignment()));
         }
 
     for (uint32_t PRN = 1; PRN <= GALILEO_E5A_NUMBER_OF_CODES; PRN++)
@@ -106,7 +111,7 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
                                     tmp_value = 0;
                                 }
                             tmp_value = tmp_value | LOCAL_CODE_FPGA_ENABLE_WRITE_MEMORY;
-                            d_ca_codes[static_cast<int32_t>(code_length_chips) * (PRN - 1) + s] = tmp_value;
+                            prn_codes_ptr_[static_cast<int32_t>(code_length_chips) * (PRN - 1) + s] = tmp_value;
 
                             tmp_value = static_cast<int32_t>(aux_code[s].real());
                             if (tmp_value < 0)
@@ -114,7 +119,7 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
                                     tmp_value = 0;
                                 }
                             tmp_value = tmp_value | LOCAL_CODE_FPGA_ENABLE_WRITE_MEMORY | LOCAL_CODE_FPGA_CORRELATOR_SELECT_COUNT;
-                            d_data_codes[static_cast<int32_t>(code_length_chips) * (PRN - 1) + s] = tmp_value;
+                            data_codes_ptr_[static_cast<int32_t>(code_length_chips) * (PRN - 1) + s] = tmp_value;
                         }
                 }
             else
@@ -128,20 +133,20 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
                                     tmp_value = 0;
                                 }
                             tmp_value = tmp_value | LOCAL_CODE_FPGA_ENABLE_WRITE_MEMORY;
-                            d_ca_codes[static_cast<int32_t>(code_length_chips) * (PRN - 1) + s] = tmp_value;
+                            prn_codes_ptr_[static_cast<int32_t>(code_length_chips) * (PRN - 1) + s] = tmp_value;
                         }
                 }
         }
 
-    trk_params_fpga.ca_codes = d_ca_codes;
-    trk_params_fpga.data_codes = d_data_codes;
+    trk_params_fpga.ca_codes = prn_codes_ptr_;
+    trk_params_fpga.data_codes = data_codes_ptr_;
     trk_params_fpga.code_length_chips = code_length_chips;
     trk_params_fpga.code_samples_per_chip = code_samples_per_chip;  // 2 sample per chip
 
     trk_params_fpga.extended_correlation_in_fpga = false;  // by default
     trk_params_fpga.extend_fpga_integration_periods = 1;   // (number of FPGA integrations that are combined in the SW)
     trk_params_fpga.fpga_integration_period = 1;           // (number of symbols that are effectively integrated in the FPGA)
-    if (d_track_pilot)
+    if (track_pilot_)
         {
             if (trk_params_fpga.extend_correlation_symbols > 1)
                 {
@@ -166,10 +171,9 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
         }
 
     // ################# MAKE TRACKING GNURadio object ###################
-    tracking_fpga_sc = dll_pll_veml_make_tracking_fpga(trk_params_fpga);
-    channel_ = 0;
-
-    DLOG(INFO) << "tracking(" << tracking_fpga_sc->unique_id() << ")";
+    DLOG(INFO) << "role " << role_;
+    tracking_fpga_sc_sptr_ = dll_pll_veml_make_tracking_fpga(trk_params_fpga);
+    DLOG(INFO) << "tracking(" << tracking_fpga_sc_sptr_->unique_id() << ")";
 
     if (in_streams_ > 1)
         {
@@ -184,23 +188,23 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
 
 GalileoE5aDllPllTrackingFpga::~GalileoE5aDllPllTrackingFpga()
 {
-    volk_gnsssdr_free(d_ca_codes);
-    if (d_track_pilot)
+    volk_gnsssdr_free(prn_codes_ptr_);
+    if (track_pilot_)
         {
-            volk_gnsssdr_free(d_data_codes);
+            volk_gnsssdr_free(data_codes_ptr_);
         }
 }
 
 
 void GalileoE5aDllPllTrackingFpga::start_tracking()
 {
-    tracking_fpga_sc->start_tracking();
+    tracking_fpga_sc_sptr_->start_tracking();
 }
 
 
 void GalileoE5aDllPllTrackingFpga::stop_tracking()
 {
-    tracking_fpga_sc->stop_tracking();
+    tracking_fpga_sc_sptr_->stop_tracking();
 }
 
 
@@ -214,18 +218,18 @@ void GalileoE5aDllPllTrackingFpga::set_channel(unsigned int channel)
     // UIO device file
     std::string device_io_name;
     // find the uio device file corresponding to the tracking multicorrelator
-    if (find_uio_dev_file_name(device_io_name, device_name, channel - num_prev_assigned_ch) < 0)
+    if (find_uio_dev_file_name(device_io_name, device_name_, channel_ - num_prev_assigned_ch_) < 0)
         {
-            std::cout << "Cannot find the FPGA uio device file corresponding to device name " << device_name << std::endl;
+            std::cout << "Cannot find the FPGA uio device file corresponding to device name " << device_name_ << std::endl;
             throw std::exception();
         }
-    tracking_fpga_sc->set_channel(channel, device_io_name);
+    tracking_fpga_sc_sptr_->set_channel(channel_, device_io_name);
 }
 
 
 void GalileoE5aDllPllTrackingFpga::set_gnss_synchro(Gnss_Synchro *p_gnss_synchro)
 {
-    tracking_fpga_sc->set_gnss_synchro(p_gnss_synchro);
+    tracking_fpga_sc_sptr_->set_gnss_synchro(p_gnss_synchro);
 }
 
 
@@ -249,11 +253,11 @@ void GalileoE5aDllPllTrackingFpga::disconnect(gr::top_block_sptr top_block)
 
 gr::basic_block_sptr GalileoE5aDllPllTrackingFpga::get_left_block()
 {
-    return tracking_fpga_sc;
+    return tracking_fpga_sc_sptr_;
 }
 
 
 gr::basic_block_sptr GalileoE5aDllPllTrackingFpga::get_right_block()
 {
-    return tracking_fpga_sc;
+    return tracking_fpga_sc_sptr_;
 }
