@@ -31,40 +31,46 @@
 
 
 GlonassL1CaDllPllCAidTracking::GlonassL1CaDllPllCAidTracking(
-    const ConfigurationInterface* configuration, const std::string& role,
-    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
+    const ConfigurationInterface* configuration,
+    const std::string& role,
+    unsigned int in_streams,
+    unsigned int out_streams)
+    : role_(role),
+      item_size_(sizeof(gr_complex)),
+      channel_(0),
+      in_streams_(in_streams),
+      out_streams_(out_streams)
 {
-    DLOG(INFO) << "role " << role;
     // ################# CONFIGURATION PARAMETERS ########################
     const std::string default_item_type("gr_complex");
-    item_type_ = configuration->property(role + ".item_type", default_item_type);
+    item_type_ = configuration->property(role_ + ".item_type", default_item_type);
     int fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000);
     int fs_in = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
-    bool dump = configuration->property(role + ".dump", false);
-    float pll_bw_hz = configuration->property(role + ".pll_bw_hz", static_cast<float>(50.0));
+    bool dump = configuration->property(role_ + ".dump", false);
+    float pll_bw_hz = configuration->property(role_ + ".pll_bw_hz", static_cast<float>(50.0));
     if (FLAGS_pll_bw_hz != 0.0)
         {
             pll_bw_hz = static_cast<float>(FLAGS_pll_bw_hz);
         }
-    float dll_bw_hz = configuration->property(role + ".dll_bw_hz", static_cast<float>(2.0));
+    float dll_bw_hz = configuration->property(role_ + ".dll_bw_hz", static_cast<float>(2.0));
     if (FLAGS_dll_bw_hz != 0.0)
         {
             dll_bw_hz = static_cast<float>(FLAGS_dll_bw_hz);
         }
-    float pll_bw_narrow_hz = configuration->property(role + ".pll_bw_narrow_hz", static_cast<float>(20.0));
-    float dll_bw_narrow_hz = configuration->property(role + ".dll_bw_narrow_hz", static_cast<float>(2.0));
-    int extend_correlation_ms = configuration->property(role + ".extend_correlation_ms", 1);
+    float pll_bw_narrow_hz = configuration->property(role_ + ".pll_bw_narrow_hz", static_cast<float>(20.0));
+    float dll_bw_narrow_hz = configuration->property(role_ + ".dll_bw_narrow_hz", static_cast<float>(2.0));
+    int extend_correlation_ms = configuration->property(role_ + ".extend_correlation_ms", 1);
 
-    float early_late_space_chips = configuration->property(role + ".early_late_space_chips", static_cast<float>(0.5));
+    float early_late_space_chips = configuration->property(role_ + ".early_late_space_chips", static_cast<float>(0.5));
     const std::string default_dump_filename("./track_ch");
-    std::string dump_filename = configuration->property(role + ".dump_filename", default_dump_filename);
+    std::string dump_filename = configuration->property(role_ + ".dump_filename", default_dump_filename);
     const auto vector_length = static_cast<int>(std::round(fs_in / (GLONASS_L1_CA_CODE_RATE_CPS / GLONASS_L1_CA_CODE_LENGTH_CHIPS)));
 
     // ################# MAKE TRACKING GNURadio object ###################
+    DLOG(INFO) << "role " << role_;
     if (item_type_ == "gr_complex")
         {
-            item_size_ = sizeof(gr_complex);
-            tracking_cc = glonass_l1_ca_dll_pll_c_aid_make_tracking_cc(
+            tracking_cc_sptr_ = glonass_l1_ca_dll_pll_c_aid_make_tracking_cc(
                 fs_in,
                 vector_length,
                 dump,
@@ -75,12 +81,13 @@ GlonassL1CaDllPllCAidTracking::GlonassL1CaDllPllCAidTracking(
                 dll_bw_narrow_hz,
                 extend_correlation_ms,
                 early_late_space_chips);
-            DLOG(INFO) << "tracking(" << tracking_cc->unique_id() << ")";
+            tracking_sc_sptr_ = nullptr;
+            DLOG(INFO) << "tracking(" << tracking_cc_sptr_->unique_id() << ")";
         }
     else if (item_type_ == "cshort")
         {
             item_size_ = sizeof(lv_16sc_t);
-            tracking_sc = glonass_l1_ca_dll_pll_c_aid_make_tracking_sc(
+            tracking_sc_sptr_ = glonass_l1_ca_dll_pll_c_aid_make_tracking_sc(
                 fs_in,
                 vector_length,
                 dump,
@@ -91,14 +98,17 @@ GlonassL1CaDllPllCAidTracking::GlonassL1CaDllPllCAidTracking(
                 dll_bw_narrow_hz,
                 extend_correlation_ms,
                 early_late_space_chips);
-            DLOG(INFO) << "tracking(" << tracking_sc->unique_id() << ")";
+            tracking_cc_sptr_ = nullptr;
+            DLOG(INFO) << "tracking(" << tracking_sc_sptr_->unique_id() << ")";
         }
     else
         {
             item_size_ = 0;
+            tracking_sc_sptr_ = nullptr;
+            tracking_cc_sptr_ = nullptr;
             LOG(WARNING) << item_type_ << " unknown tracking item type.";
         }
-    channel_ = 0;
+
     if (in_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one input stream";
@@ -119,11 +129,11 @@ void GlonassL1CaDllPllCAidTracking::start_tracking()
 {
     if (item_type_ == "gr_complex")
         {
-            tracking_cc->start_tracking();
+            tracking_cc_sptr_->start_tracking();
         }
     else if (item_type_ == "cshort")
         {
-            tracking_sc->start_tracking();
+            tracking_sc_sptr_->start_tracking();
         }
     else
         {
@@ -141,11 +151,11 @@ void GlonassL1CaDllPllCAidTracking::set_channel(unsigned int channel)
 
     if (item_type_ == "gr_complex")
         {
-            tracking_cc->set_channel(channel);
+            tracking_cc_sptr_->set_channel(channel);
         }
     else if (item_type_ == "cshort")
         {
-            tracking_sc->set_channel(channel);
+            tracking_sc_sptr_->set_channel(channel);
         }
     else
         {
@@ -158,11 +168,11 @@ void GlonassL1CaDllPllCAidTracking::set_gnss_synchro(Gnss_Synchro* p_gnss_synchr
 {
     if (item_type_ == "gr_complex")
         {
-            tracking_cc->set_gnss_synchro(p_gnss_synchro);
+            tracking_cc_sptr_->set_gnss_synchro(p_gnss_synchro);
         }
     else if (item_type_ == "cshort")
         {
-            tracking_sc->set_gnss_synchro(p_gnss_synchro);
+            tracking_sc_sptr_->set_gnss_synchro(p_gnss_synchro);
         }
     else
         {
@@ -193,11 +203,11 @@ gr::basic_block_sptr GlonassL1CaDllPllCAidTracking::get_left_block()
 {
     if (item_type_ == "gr_complex")
         {
-            return tracking_cc;
+            return tracking_cc_sptr_;
         }
     if (item_type_ == "cshort")
         {
-            return tracking_sc;
+            return tracking_sc_sptr_;
         }
     LOG(WARNING) << item_type_ << " unknown tracking item type";
     return nullptr;
@@ -208,11 +218,11 @@ gr::basic_block_sptr GlonassL1CaDllPllCAidTracking::get_right_block()
 {
     if (item_type_ == "gr_complex")
         {
-            return tracking_cc;
+            return tracking_cc_sptr_;
         }
     if (item_type_ == "cshort")
         {
-            return tracking_sc;
+            return tracking_sc_sptr_;
         }
 
 
