@@ -30,36 +30,42 @@
 
 
 GlonassL1CaDllPllTracking::GlonassL1CaDllPllTracking(
-    const ConfigurationInterface* configuration, const std::string& role,
-    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
+    const ConfigurationInterface* configuration,
+    const std::string& role,
+    unsigned int in_streams,
+    unsigned int out_streams)
+    : role_(role),
+      item_size_(sizeof(gr_complex)),
+      channel_(0),
+      in_streams_(in_streams),
+      out_streams_(out_streams)
 {
-    DLOG(INFO) << "role " << role;
     // ################# CONFIGURATION PARAMETERS ########################
     const std::string default_item_type("gr_complex");
-    std::string item_type = configuration->property(role + ".item_type", default_item_type);
+    std::string item_type = configuration->property(role_ + ".item_type", default_item_type);
     int fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000);
     int fs_in = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
-    bool dump = configuration->property(role + ".dump", false);
-    float pll_bw_hz = configuration->property(role + ".pll_bw_hz", static_cast<float>(50.0));
+    bool dump = configuration->property(role_ + ".dump", false);
+    float pll_bw_hz = configuration->property(role_ + ".pll_bw_hz", static_cast<float>(50.0));
     if (FLAGS_pll_bw_hz != 0.0)
         {
             pll_bw_hz = static_cast<float>(FLAGS_pll_bw_hz);
         }
-    float dll_bw_hz = configuration->property(role + ".dll_bw_hz", static_cast<float>(2.0));
+    float dll_bw_hz = configuration->property(role_ + ".dll_bw_hz", static_cast<float>(2.0));
     if (FLAGS_dll_bw_hz != 0.0)
         {
             dll_bw_hz = static_cast<float>(FLAGS_dll_bw_hz);
         }
-    float early_late_space_chips = configuration->property(role + ".early_late_space_chips", static_cast<float>(0.5));
+    float early_late_space_chips = configuration->property(role_ + ".early_late_space_chips", static_cast<float>(0.5));
     const std::string default_dump_filename("./track_ch");
-    std::string dump_filename = configuration->property(role + ".dump_filename", default_dump_filename);
+    std::string dump_filename = configuration->property(role_ + ".dump_filename", default_dump_filename);
     const auto vector_length = static_cast<int>(std::round(fs_in / (GLONASS_L1_CA_CODE_RATE_CPS / GLONASS_L1_CA_CODE_LENGTH_CHIPS)));
 
     // ################# MAKE TRACKING GNURadio object ###################
+    DLOG(INFO) << "role " << role_;
     if (item_type == "gr_complex")
         {
-            item_size_ = sizeof(gr_complex);
-            tracking_ = glonass_l1_ca_dll_pll_make_tracking_cc(
+            tracking_sptr_ = glonass_l1_ca_dll_pll_make_tracking_cc(
                 fs_in,
                 vector_length,
                 dump,
@@ -67,14 +73,15 @@ GlonassL1CaDllPllTracking::GlonassL1CaDllPllTracking(
                 pll_bw_hz,
                 dll_bw_hz,
                 early_late_space_chips);
+            DLOG(INFO) << "tracking(" << tracking_sptr_->unique_id() << ")";
         }
     else
         {
-            item_size_ = sizeof(gr_complex);
+            item_size_ = 0;
+            tracking_sptr_ = nullptr;
             LOG(WARNING) << item_type << " unknown tracking item type.";
         }
-    channel_ = 0;
-    DLOG(INFO) << "tracking(" << tracking_->unique_id() << ")";
+
     if (in_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one input stream";
@@ -93,7 +100,7 @@ void GlonassL1CaDllPllTracking::stop_tracking()
 
 void GlonassL1CaDllPllTracking::start_tracking()
 {
-    tracking_->start_tracking();
+    tracking_sptr_->start_tracking();
 }
 
 
@@ -103,13 +110,13 @@ void GlonassL1CaDllPllTracking::start_tracking()
 void GlonassL1CaDllPllTracking::set_channel(unsigned int channel)
 {
     channel_ = channel;
-    tracking_->set_channel(channel);
+    tracking_sptr_->set_channel(channel);
 }
 
 
 void GlonassL1CaDllPllTracking::set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
 {
-    tracking_->set_gnss_synchro(p_gnss_synchro);
+    tracking_sptr_->set_gnss_synchro(p_gnss_synchro);
 }
 
 
@@ -133,11 +140,11 @@ void GlonassL1CaDllPllTracking::disconnect(gr::top_block_sptr top_block)
 
 gr::basic_block_sptr GlonassL1CaDllPllTracking::get_left_block()
 {
-    return tracking_;
+    return tracking_sptr_;
 }
 
 
 gr::basic_block_sptr GlonassL1CaDllPllTracking::get_right_block()
 {
-    return tracking_;
+    return tracking_sptr_;
 }
