@@ -28,15 +28,21 @@
 #include "dll_pll_conf.h"
 #include "gnss_sdr_flags.h"
 #include <glog/logging.h>
+#include <algorithm>
 #include <array>
 
 GpsL1CaDllPllTracking::GpsL1CaDllPllTracking(
-    const ConfigurationInterface* configuration, const std::string& role,
-    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
+    const ConfigurationInterface* configuration,
+    const std::string& role,
+    unsigned int in_streams, unsigned int out_streams)
+    : role_(role),
+      item_size_(sizeof(gr_complex)),
+      channel_(0),
+      in_streams_(in_streams),
+      out_streams_(out_streams)
 {
     Dll_Pll_Conf trk_params = Dll_Pll_Conf();
-    DLOG(INFO) << "role " << role;
-    trk_params.SetFromConfiguration(configuration, role);
+    trk_params.SetFromConfiguration(configuration, role_);
 
     const auto vector_length = static_cast<int>(std::round(trk_params.fs_in / (GPS_L1_CA_CODE_RATE_CPS / GPS_L1_CA_CODE_LENGTH_CHIPS)));
     trk_params.vector_length = vector_length;
@@ -50,7 +56,7 @@ GpsL1CaDllPllTracking::GpsL1CaDllPllTracking(
             trk_params.extend_correlation_symbols = 20;
             std::cout << TEXT_RED << "WARNING: GPS L1 C/A. extend_correlation_symbols must be lower than 21. Coherent integration has been set to 20 symbols (20 ms)" << TEXT_RESET << '\n';
         }
-    trk_params.track_pilot = configuration->property(role + ".track_pilot", false);
+    trk_params.track_pilot = configuration->property(role_ + ".track_pilot", false);
     if (trk_params.track_pilot)
         {
             trk_params.track_pilot = false;
@@ -62,22 +68,23 @@ GpsL1CaDllPllTracking::GpsL1CaDllPllTracking(
         }
 
     trk_params.system = 'G';
-    const std::array<char, 3> sig_{'1', 'C', '\0'};
-    std::memcpy(trk_params.signal, sig_.data(), 3);
+    const std::array<char, 3> sig{'1', 'C', '\0'};
+    std::copy_n(sig.data(), 3, trk_params.signal);
 
     // ################# Make a GNU Radio Tracking block object ################
+    DLOG(INFO) << "role " << role_;
     if (trk_params.item_type == "gr_complex")
         {
-            item_size_ = sizeof(gr_complex);
-            tracking_ = dll_pll_veml_make_tracking(trk_params);
+            tracking_sptr_ = dll_pll_veml_make_tracking(trk_params);
+            DLOG(INFO) << "tracking(" << tracking_sptr_->unique_id() << ")";
         }
     else
         {
             item_size_ = 0;
+            tracking_sptr_ = nullptr;
             LOG(WARNING) << trk_params.item_type << " unknown tracking item type.";
         }
-    channel_ = 0;
-    DLOG(INFO) << "tracking(" << tracking_->unique_id() << ")";
+
     if (in_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one input stream";
@@ -91,13 +98,13 @@ GpsL1CaDllPllTracking::GpsL1CaDllPllTracking(
 
 void GpsL1CaDllPllTracking::stop_tracking()
 {
-    tracking_->stop_tracking();
+    tracking_sptr_->stop_tracking();
 }
 
 
 void GpsL1CaDllPllTracking::start_tracking()
 {
-    tracking_->start_tracking();
+    tracking_sptr_->start_tracking();
 }
 
 
@@ -107,13 +114,13 @@ void GpsL1CaDllPllTracking::start_tracking()
 void GpsL1CaDllPllTracking::set_channel(unsigned int channel)
 {
     channel_ = channel;
-    tracking_->set_channel(channel);
+    tracking_sptr_->set_channel(channel);
 }
 
 
 void GpsL1CaDllPllTracking::set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
 {
-    tracking_->set_gnss_synchro(p_gnss_synchro);
+    tracking_sptr_->set_gnss_synchro(p_gnss_synchro);
 }
 
 
@@ -137,11 +144,11 @@ void GpsL1CaDllPllTracking::disconnect(gr::top_block_sptr top_block)
 
 gr::basic_block_sptr GpsL1CaDllPllTracking::get_left_block()
 {
-    return tracking_;
+    return tracking_sptr_;
 }
 
 
 gr::basic_block_sptr GpsL1CaDllPllTracking::get_right_block()
 {
-    return tracking_;
+    return tracking_sptr_;
 }
