@@ -30,15 +30,22 @@
 #include "uio_fpga.h"
 #include <glog/logging.h>
 #include <volk_gnsssdr/volk_gnsssdr.h>
+#include <algorithm>
 #include <array>
 
 GpsL1CaDllPllTrackingFpga::GpsL1CaDllPllTrackingFpga(
-    const ConfigurationInterface* configuration, const std::string& role,
-    unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
+    const ConfigurationInterface* configuration,
+    const std::string& role,
+    unsigned int in_streams,
+    unsigned int out_streams)
+    : role_(role),
+      num_prev_assigned_ch_(0),
+      channel_(0),
+      in_streams_(in_streams),
+      out_streams_(out_streams)
 {
     Dll_Pll_Conf_Fpga trk_params_fpga = Dll_Pll_Conf_Fpga();
-    DLOG(INFO) << "role " << role;
-    trk_params_fpga.SetFromConfiguration(configuration, role);
+    trk_params_fpga.SetFromConfiguration(configuration, role_);
 
     const auto vector_length = static_cast<int32_t>(std::round(trk_params_fpga.fs_in / (GPS_L1_CA_CODE_RATE_CPS / GPS_L1_CA_CODE_LENGTH_CHIPS)));
     trk_params_fpga.vector_length = vector_length;
@@ -52,7 +59,7 @@ GpsL1CaDllPllTrackingFpga::GpsL1CaDllPllTrackingFpga(
             trk_params_fpga.extend_correlation_symbols = GPS_CA_BIT_DURATION_MS;
             std::cout << TEXT_RED << "WARNING: GPS L1 C/A. extend_correlation_symbols must be lower than 21. Coherent integration has been set to 20 symbols (20 ms)" << TEXT_RESET << '\n';
         }
-    trk_params_fpga.track_pilot = configuration->property(role + ".track_pilot", false);
+    trk_params_fpga.track_pilot = configuration->property(role_ + ".track_pilot", false);
     if (trk_params_fpga.track_pilot)
         {
             trk_params_fpga.track_pilot = false;
@@ -63,35 +70,31 @@ GpsL1CaDllPllTrackingFpga::GpsL1CaDllPllTrackingFpga(
             std::cout << TEXT_RED << "WARNING: GPS L1 C/A. PLL or DLL narrow tracking bandwidth is higher than wide tracking one" << TEXT_RESET << '\n';
         }
     trk_params_fpga.system = 'G';
-    const std::array<char, 3> sig_{'1', 'C', '\0'};
-    std::memcpy(trk_params_fpga.signal, sig_.data(), 3);
+    const std::array<char, 3> sig{'1', 'C', '\0'};
+    std::copy_n(sig.data(), 3, trk_params_fpga.signal);
 
     // UIO device file
-    device_name = configuration->property(role + ".devicename", default_device_name_GPS_L1);
-
-    // compute the number of tracking channels that have already been instantiated. The order in which
-    // GNSS-SDR instantiates the tracking channels i L1, l2, L5, E1, E5a
-    num_prev_assigned_ch = 0;
+    device_name_ = configuration->property(role_ + ".devicename", default_device_name_GPS_L1);
 
     // ################# PRE-COMPUTE ALL THE CODES #################
-    d_ca_codes = static_cast<int32_t*>(volk_gnsssdr_malloc(static_cast<int32_t>(GPS_L1_CA_CODE_LENGTH_CHIPS * NUM_PRNs) * sizeof(int32_t), volk_gnsssdr_get_alignment()));
+    ca_codes_ptr_ = static_cast<int32_t*>(volk_gnsssdr_malloc(static_cast<int32_t>(GPS_L1_CA_CODE_LENGTH_CHIPS * NUM_PRNs) * sizeof(int32_t), volk_gnsssdr_get_alignment()));
     for (uint32_t PRN = 1; PRN <= NUM_PRNs; PRN++)
         {
-            gps_l1_ca_code_gen_int(own::span<int32_t>(&d_ca_codes[static_cast<int32_t>(GPS_L1_CA_CODE_LENGTH_CHIPS) * (PRN - 1)], &d_ca_codes[static_cast<int32_t>(GPS_L1_CA_CODE_LENGTH_CHIPS) * (PRN)]), PRN, 0);
+            gps_l1_ca_code_gen_int(own::span<int32_t>(&ca_codes_ptr_[static_cast<int32_t>(GPS_L1_CA_CODE_LENGTH_CHIPS) * (PRN - 1)], &ca_codes_ptr_[static_cast<int32_t>(GPS_L1_CA_CODE_LENGTH_CHIPS) * (PRN)]), PRN, 0);
 
             // The code is generated as a series of 1s and -1s. In order to store the values using only one bit, a -1 is stored as a 0 in the FPGA
             for (uint32_t k = 0; k < GPS_L1_CA_CODE_LENGTH_CHIPS; k++)
                 {
-                    int32_t tmp_value = d_ca_codes[(int32_t(GPS_L1_CA_CODE_LENGTH_CHIPS)) * (PRN - 1) + k];
+                    int32_t tmp_value = ca_codes_ptr_[(int32_t(GPS_L1_CA_CODE_LENGTH_CHIPS)) * (PRN - 1) + k];
                     if (tmp_value < 0)
                         {
                             tmp_value = 0;
                         }
                     tmp_value = tmp_value | LOCAL_CODE_FPGA_ENABLE_WRITE_MEMORY;
-                    d_ca_codes[(int32_t(GPS_L1_CA_CODE_LENGTH_CHIPS)) * (PRN - 1) + k] = tmp_value;
+                    ca_codes_ptr_[(int32_t(GPS_L1_CA_CODE_LENGTH_CHIPS)) * (PRN - 1) + k] = tmp_value;
                 }
         }
-    trk_params_fpga.ca_codes = d_ca_codes;
+    trk_params_fpga.ca_codes = ca_codes_ptr_;
     trk_params_fpga.code_length_chips = GPS_L1_CA_CODE_LENGTH_CHIPS;
     trk_params_fpga.code_samples_per_chip = 1;  // 1 sample per chip
 
@@ -111,9 +114,9 @@ GpsL1CaDllPllTrackingFpga::GpsL1CaDllPllTrackingFpga(
         }
 
     // ################# MAKE TRACKING GNU Radio object ###################
-    tracking_fpga_sc = dll_pll_veml_make_tracking_fpga(trk_params_fpga);
-    channel_ = 0;
-    DLOG(INFO) << "tracking(" << tracking_fpga_sc->unique_id() << ")";
+    DLOG(INFO) << "role " << role_;
+    tracking_fpga_sc_sptr_ = dll_pll_veml_make_tracking_fpga(trk_params_fpga);
+    DLOG(INFO) << "tracking(" << tracking_fpga_sc_sptr_->unique_id() << ")";
 
     if (in_streams_ > 1)
         {
@@ -128,19 +131,19 @@ GpsL1CaDllPllTrackingFpga::GpsL1CaDllPllTrackingFpga(
 
 GpsL1CaDllPllTrackingFpga::~GpsL1CaDllPllTrackingFpga()
 {
-    volk_gnsssdr_free(d_ca_codes);
+    volk_gnsssdr_free(ca_codes_ptr_);
 }
 
 
 void GpsL1CaDllPllTrackingFpga::start_tracking()
 {
-    tracking_fpga_sc->start_tracking();
+    tracking_fpga_sc_sptr_->start_tracking();
 }
 
 
 void GpsL1CaDllPllTrackingFpga::stop_tracking()
 {
-    tracking_fpga_sc->stop_tracking();
+    tracking_fpga_sc_sptr_->stop_tracking();
 }
 
 
@@ -155,16 +158,16 @@ void GpsL1CaDllPllTrackingFpga::set_channel(unsigned int channel)
     std::string device_io_name;
 
     // find the uio device file corresponding to the tracking multicorrelator
-    if (find_uio_dev_file_name(device_io_name, device_name, channel - num_prev_assigned_ch) < 0)
+    if (find_uio_dev_file_name(device_io_name, device_name_, channel_ - num_prev_assigned_ch_) < 0)
         {
             bool alt_device_found = false;  // alternative compatible HW accelerator device not found by default
 
             // If the HW accelerator is the default one in the L1 band then look for an alternative hardware accelerator
-            if (device_name == default_device_name_GPS_L1)
+            if (device_name_ == default_device_name_GPS_L1)
                 {
-                    if (find_uio_dev_file_name(device_io_name, default_device_name_Galileo_E1, channel - num_prev_assigned_ch) < 0)
+                    if (find_uio_dev_file_name(device_io_name, default_device_name_Galileo_E1, channel_ - num_prev_assigned_ch_) < 0)
                         {
-                            std::cout << "Cannot find the FPGA uio device file corresponding to device names " << device_name << " or " << default_device_name_Galileo_E1 << std::endl;
+                            std::cout << "Cannot find the FPGA uio device file corresponding to device names " << device_name_ << " or " << default_device_name_Galileo_E1 << std::endl;
                             throw std::exception();
                         }
                     else
@@ -175,18 +178,18 @@ void GpsL1CaDllPllTrackingFpga::set_channel(unsigned int channel)
 
             if (!alt_device_found)
                 {
-                    std::cout << "Cannot find the FPGA uio device file corresponding to device name " << device_name << std::endl;
+                    std::cout << "Cannot find the FPGA uio device file corresponding to device name " << device_name_ << std::endl;
                     throw std::exception();
                 }
         }
 
-    tracking_fpga_sc->set_channel(channel, device_io_name);
+    tracking_fpga_sc_sptr_->set_channel(channel_, device_io_name);
 }
 
 
 void GpsL1CaDllPllTrackingFpga::set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
 {
-    tracking_fpga_sc->set_gnss_synchro(p_gnss_synchro);
+    tracking_fpga_sc_sptr_->set_gnss_synchro(p_gnss_synchro);
 }
 
 
@@ -210,11 +213,11 @@ void GpsL1CaDllPllTrackingFpga::disconnect(gr::top_block_sptr top_block)
 
 gr::basic_block_sptr GpsL1CaDllPllTrackingFpga::get_left_block()
 {
-    return tracking_fpga_sc;
+    return tracking_fpga_sc_sptr_;
 }
 
 
 gr::basic_block_sptr GpsL1CaDllPllTrackingFpga::get_right_block()
 {
-    return tracking_fpga_sc;
+    return tracking_fpga_sc_sptr_;
 }
