@@ -20,22 +20,6 @@
 #include "tracking_FLL_PLL_filter.h"
 
 
-Tracking_FLL_PLL_filter::Tracking_FLL_PLL_filter()
-{
-    d_order = 0;
-    d_pll_w = 0.0;
-    d_pll_w0p3 = 0.0;
-    d_pll_w0f2 = 0.0;
-    d_pll_x = 0.0;
-    d_pll_a2 = 0.0;
-    d_pll_w0f = 0.0;
-    d_pll_a3 = 0.0;
-    d_pll_w0p2 = 0.0;
-    d_pll_b3 = 0.0;
-    d_pll_w0p = 0.0;
-}
-
-
 void Tracking_FLL_PLL_filter::set_params(float fll_bw_hz, float pll_bw_hz, int order)
 {
     /*
