@@ -29,7 +29,7 @@
 class Tracking_FLL_PLL_filter
 {
 public:
-    Tracking_FLL_PLL_filter();
+    Tracking_FLL_PLL_filter() = default;
     ~Tracking_FLL_PLL_filter() = default;
     void set_params(float fll_bw_hz, float pll_bw_hz, int order);
     void initialize(float d_acq_carrier_doppler_hz);
@@ -37,17 +37,17 @@ public:
 
 private:
     // FLL + PLL filter parameters
-    float d_pll_w;
-    float d_pll_w0p3;
-    float d_pll_w0f2;
-    float d_pll_x;
-    float d_pll_a2;
-    float d_pll_w0f;
-    float d_pll_a3;
-    float d_pll_w0p2;
-    float d_pll_b3;
-    float d_pll_w0p;
-    int d_order;
+    float d_pll_w{0.0};
+    float d_pll_w0p3{0.0};
+    float d_pll_w0f2{0.0};
+    float d_pll_x{0.0};
+    float d_pll_a2{0.0};
+    float d_pll_w0f{0.0};
+    float d_pll_a3{0.0};
+    float d_pll_w0p2{0.0};
+    float d_pll_b3{0.0};
+    float d_pll_w0p{0.0};
+    int d_order{0};
 };
 
 
