@@ -5,18 +5,15 @@
  *         Carles Fernandez-Prades, 2012. cfernandez(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include <armadillo>
@@ -47,7 +44,7 @@ TEST(MultiplyTest, StandardCDoubleImplementation)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << " doubles in standard C finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
 
     double acc = 0.0;
     double expected = 0.0;
@@ -76,7 +73,7 @@ TEST(MultiplyTest, ArmadilloImplementation)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << "-length double Armadillo vectors finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
     ASSERT_LE(0, elapsed_seconds.count() * 1e6);
     ASSERT_EQ(0, arma::norm(output, 2));
 }
@@ -99,7 +96,7 @@ TEST(MultiplyTest, StandardCComplexImplementation)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << " complex<float> in standard C finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
 
     std::complex<float> expected(0.0, 0.0);
     std::complex<float> result(0.0, 0.0);
@@ -132,7 +129,7 @@ TEST(MultiplyTest, C11ComplexImplementation)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << " complex<float> vector (C++11-style) finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
     ASSERT_LE(0, elapsed_seconds.count() * 1e6);
 
     std::complex<float> expected(0.0, 0.0);
@@ -155,7 +152,7 @@ TEST(MultiplyTest, ArmadilloComplexImplementation)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << "-length complex float Armadillo vectors finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
     ASSERT_LE(0, elapsed_seconds.count() * 1e6);
     ASSERT_EQ(0, arma::norm(output, 2));
 }
@@ -176,7 +173,7 @@ TEST(MultiplyTest, VolkComplexImplementation)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << "-length complex float vector using VOLK finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
     ASSERT_LE(0, elapsed_seconds.count() * 1e6);
 
     auto* mag = static_cast<float*>(volk_gnsssdr_malloc(FLAGS_size_multiply_test * sizeof(float), volk_gnsssdr_get_alignment()));
@@ -209,7 +206,7 @@ TEST(MultiplyTest, VolkComplexImplementationAlloc)
     std::chrono::duration<double> elapsed_seconds = end - start;
     std::cout << "Element-wise multiplication of " << FLAGS_size_multiply_test
               << "-length complex float vector using VOLK ALLOC finished in " << elapsed_seconds.count() * 1e6
-              << " microseconds" << std::endl;
+              << " microseconds\n";
     ASSERT_LE(0, elapsed_seconds.count() * 1e6);
     volk_gnsssdr::vector<float> mag(FLAGS_size_multiply_test);
     volk_32fc_magnitude_32f(mag.data(), output.data(), FLAGS_size_multiply_test);
