@@ -4,23 +4,22 @@
  * \author Carles Fernandez-Prades, 2012. cfernandez(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
 #include "file_configuration.h"
+#include "gnss_sdr_make_unique.h"
 #include <string>
+#include <utility>
 
 
 TEST(FileConfigurationTest, OverridedProperties)
@@ -28,21 +27,21 @@ TEST(FileConfigurationTest, OverridedProperties)
     std::string path = std::string(TEST_PATH);
     std::string filename = path + "data/config_file_sample.txt";
     // std::shared_ptr<ConfigurationInterface> configuration = std::make_shared<FileConfiguration>(filename);
-    std::unique_ptr<ConfigurationInterface> configuration(new FileConfiguration(filename));
+    std::unique_ptr<ConfigurationInterface> configuration = std::make_unique<FileConfiguration>(filename);
     std::string default_value = "default_value";
     std::string value = configuration->property("NotThere", default_value);
     EXPECT_STREQ("default_value", value.c_str());
     configuration->set_property("NotThere", "Yes!");
-    value = configuration->property("NotThere", default_value);
+    value = configuration->property("NotThere", std::move(default_value));
     EXPECT_STREQ("Yes!", value.c_str());
 }
 
 
 TEST(FileConfigurationTest, LoadFromNonExistentFile)
 {
-    std::unique_ptr<ConfigurationInterface> configuration(new FileConfiguration("./i_dont_exist.conf"));
+    std::unique_ptr<ConfigurationInterface> configuration = std::make_unique<FileConfiguration>("./i_dont_exist.conf");
     std::string default_value = "default_value";
-    std::string value = configuration->property("whatever.whatever", default_value);
+    std::string value = configuration->property("whatever.whatever", std::move(default_value));
     EXPECT_STREQ("default_value", value.c_str());
 }
 
@@ -51,8 +50,8 @@ TEST(FileConfigurationTest, PropertyDoesNotExist)
 {
     std::string path = std::string(TEST_PATH);
     std::string filename = path + "data/config_file_sample.txt";
-    std::unique_ptr<ConfigurationInterface> configuration(new FileConfiguration(filename));
+    std::unique_ptr<ConfigurationInterface> configuration = std::make_unique<FileConfiguration>(filename);
     std::string default_value = "default_value";
-    std::string value = configuration->property("whatever.whatever", default_value);
+    std::string value = configuration->property("whatever.whatever", std::move(default_value));
     EXPECT_STREQ("default_value", value.c_str());
 }
