@@ -18,6 +18,7 @@
 #include "gnss_sdr_make_unique.h"
 #include "gnss_sdr_supl_client.h"
 #include "in_memory_configuration.h"
+#include "pvt_conf.h"
 #include "rtklib_solver.h"
 #include <armadillo>
 #include <boost/archive/xml_iarchive.hpp>
@@ -28,7 +29,6 @@
 #include <iostream>
 #include <string>
 
-
 rtk_t configure_rtklib_options()
 {
     std::shared_ptr<InMemoryConfiguration> configuration;
@@ -384,7 +384,9 @@ TEST(RTKLibSolverTest, test1)
     bool save_to_mat = false;
     rtk_t rtk = configure_rtklib_options();
 
-    auto d_ls_pvt = std::make_unique<Rtklib_Solver>(rtk, nchannels, dump_filename, 1, flag_dump_to_file, save_to_mat);
+    Pvt_Conf conf;
+    conf.use_e6_for_pvt = false;
+    auto d_ls_pvt = std::make_unique<Rtklib_Solver>(rtk, conf, nchannels, dump_filename, 1, flag_dump_to_file, save_to_mat);
     d_ls_pvt->set_averaging_depth(1);
 
     // load ephemeris
